@@ -34,8 +34,8 @@ use tonic::Request;
 
 use crate::replication::health::ReplicationHealthManager;
 use crate::settings::Settings;
+use crate::shards::cache::ShardWriterCache;
 use crate::shards::metadata::ShardMetadata;
-use crate::shards::providers::shard_cache::ShardWriterCache;
 use crate::shards::writer::ShardWriter;
 use crate::utils::{list_shards, set_primary_node_id};
 
@@ -145,8 +145,9 @@ pub async fn replicate_shard(
     // GC after replication to clean up old segments
     // We only do this here because GC will not be done otherwise on a secondary
     // XXX this should be removed once we refactor gc/merging
+    shard.reload()?;
     let sshard = Arc::clone(&shard); // moved shard for gc
-    tokio::task::spawn_blocking(move || sshard.gc()).await?.expect("GC failed");
+    tokio::task::spawn_blocking(move || sshard.collect_garbage()).await?.expect("GC failed");
 
     Ok(())
 }
