@@ -34,8 +34,8 @@ use nucliadb_node::merge::errors::MergerError;
 use nucliadb_node::settings::providers::env::EnvSettingsProvider;
 use nucliadb_node::settings::providers::SettingsProvider;
 use nucliadb_node::settings::Settings;
+use nucliadb_node::shards::cache::ShardWriterCache;
 use nucliadb_node::shards::metadata::ShardMetadata;
-use nucliadb_node::shards::providers::shard_cache::ShardWriterCache;
 use nucliadb_node::shards::writer::ShardWriter;
 use prost::Message;
 use pyo3::exceptions::PyValueError;
